[![PyPI badge](https://img.shields.io/pypi/v/scitacean.svg?style=flat-square&color=green)](https://pypi.python.org/pypi/scitacean)
[![Anaconda-Server Badge](https://img.shields.io/conda/vn/conda-forge/scitacean?style=flat-square&color=green)](https://anaconda.org/conda-forge/scitacean)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7554718.svg)](https://doi.org/10.5281/zenodo.7554718)
[![License: BSD 3-Clause](https://img.shields.io/github/license/SciCatProject/scitacean?style=flat-square&color=yellowgreen)](LICENSE)

# Scitacean

Scitacean is a high level Python package for downloading and uploading datasets from and to [SciCat](https://scicatproject.github.io/).

See the [documentation](https://scicatproject.github.io/scitacean/) for installation and usage instructions.

If you need help, have a look at our GitHub [discussions](https://github.com/SciCatProject/scitacean/discussions).
For questions, please start a [Q&A discussion](https://github.com/SciCatProject/scitacean/discussions/categories/q-a) if you can't find an answer.
